% Generated by roxygen2 (4.1.0): do not edit by hand
% Please edit documentation in R/dbacf-package.R
\docType{package}
\name{dbacf-package}
\alias{dbacf-package}
\title{Difference-based (auto)covariance-correlation estimation in change-point
 regression with stationary \eqn{m}-dependent errors}
\description{
Provides minimally biased methods for (auto)covariance-correlation
 estimation in change-point regression with stationary \eqn{m}-dependent errors
 without having to pre-estimate the underlying signal of the observations.
 It includes a graphical method to select the level of dependency, \eqn{m},
 and a general projection-based method for covariance matrix estimation.
 This package implements the methods presented in
 \cite{Munk and Tecuapetla-Gómez (2015)}.
}
\note{
Although theoretical properties of the methods implemented
 in this package were derived for change-point regression with stationary
 \emph{Gaussian} \eqn{m}-dependent errors, these methods have proven robust against
 non-normality of the errors and as efficient as other methods in which
 pre-estimation of an underlying smooth signal is required. For further
 details see Section 5 of \cite{Munk and Tecuapetla-Gómez (2015)}.
}
\section{Autocovariance Estimation}{

 \code{\link{dbacf}} returns \emph{and plots by default} (auto)covariance-correlation
 estimates without pre-estimating the underlying \emph{not necessarily smooth}
 signal of observations with \emph{stationary} \eqn{m}-dependent errors. This
 function returns invisibly an S3 object of class \code{dbacf}. The corresponding
 plot method \code{\link[dbacf]{plot.dbacf}} allows for adjusting graphical
 parameters to users' liking.
}

\section{Selection of Level of Dependency \eqn{\mathbf{m}}{m}}{

 \code{\link[dbacf]{selectM}} can be used
 to select \eqn{m} in change-point regression with stationary \eqn{m}-dependent errors;
 no pre-estimation of the underlying signal is required.
 An invisible S3 object of class \code{selectM} is returned. See also
 \code{\link[dbacf]{plot.selectM}}.
}

\section{Covariance Matrix Estimation}{

 Given a matrix estimate, \emph{not necessarily positive definite}, of
 the covariance matrix of a stationary process,
 \code{\link{nearPDToeplitz}} returns the nearest, \emph{in the Frobenius norm},
 covariance matrix to the initial estimate. See \code{\link{projectToeplitz}}
 for the projection of a given symmetric matrix onto the space of Toeplitz matrices.
 See also \code{\link{symBandedToeplitz}} for creating a (stationary process'
 large covariance) matrix by specifying its dimension and values of its
 autocovariance function.
}
\author{
Tecuapetla-Gómez, I. \email{itecuap@mathematik.uni-goettingen.de}
}
\references{
Grigoriadis, K.M., Frazho, A., Skelton, R. (1994).
  \emph{Application of alternating convex projection methods for computation
  of positive Toeplitz matrices}, IEEE Transactions on signal processing
  \bold{42(7)}, 1873--1875.

N. Higham (2002). \emph{Computing the nearest correlation matrix - a
  problem from finance}, Journal of Numerical Analysis \bold{22}, 329--343.

Munk, A. and Tecuapetla-Gómez, I. (2015). \emph{Autocovariance
 estimation in change-point regression with \eqn{m}-dependent errors: A
 difference-based approach}. Submitted.
}
\keyword{package}

