% Generated by roxygen2 (4.1.0): do not edit by hand
% Please edit documentation in R/dbacf.R
\name{dbacf}
\alias{dbacf}
\title{Difference-based (auto)covariance-correlation function estimation}
\usage{
dbacf(data, m, d, type = c("covariance", "correlation"), plot = TRUE, ...)
}
\arguments{
\item{data}{numeric vector or a univariate object of class
               \code{\link[stats]{ts}} of length at least \code{2(m + 1)}.}

\item{m}{integer scalar giving the underlying level of dependency.}

\item{d}{numeric vector giving the weights used in difference-based
               estimation method. If missing, the weights \code{d} are
               calculated according to Eqs. (1.11)-(1.12) of
               \cite{Munk and Tecuapetla-Gómez (2015)}.
               When a single value \eqn{d^\ast}{d*} is specified,
               \code{d = rep(}\eqn{d^\ast}{d*}\code{, m + 1)}.}

\item{type}{character string specifying the type of acf to be computed.}

\item{plot}{logical. If \code{TRUE} (default) the acf is plotted.}

\item{\dots}{further arguments passed to \code{\link{plot.dbacf}}.}
}
\value{
An object of class "dbacf" containing:
 \item{acf}{numeric vector of length \code{m + 1} giving estimated
            (auto)covariance-correlation.}
 \item{m}{integer giving underlying level of dependency.}
 \item{d}{numeric vector containing the weights used to estimate acf.}
 \item{acfType}{string indicating whether \code{covariance} or
                \code{correlation} has been computed.}
 \item{n}{integer giving \code{length(data)}.}
 \item{series}{string with name of variable \code{data}.}
}
\description{
Computes \emph{and by default plots} the (auto)covariance-correlation function
 estimate without pre-estimating the underlying \emph{piecewise constant signal}
 of the observations. To that end, a class of second-order
 \emph{difference-based estimators} is implemented according to Eqs. (1.6)-(1.7)
 of \cite{Munk and Tecuapetla-Gómez (2015)}. By default, this function computes
 a subclass of estimates with minimal bias according to Eqs. (1.11)-(1.12) of
 aforementioned paper.
}
\note{
Although the theoretical properties of the methods implemented
 in this function were derived for change-point regression with stationary
 \emph{Gaussian} \eqn{m}-dependent errors, these methods have proven robust against
 non-normality of the errors and as efficient as other methods in which
 pre-estimation of an underlying smooth signal is required; the parameter
 \eqn{m} is essential though, see \code{\link[dbacf]{selectM}}. For further
 details see Section 5 and 6 of \cite{Munk and Tecuapetla-Gómez (2015)}.
}
\examples{
ma2 <- arima.sim(n = 50, model = list(ma = c(0.4, -0.4), order = c(0, 0, 2)),
                 sd = 0.25)
dbacf(ma2, m = 2)
}
\references{
Munk, A. and Tecuapetla-Gómez, I. (2015). \emph{Autocovariance
 estimation in change-point regression with \eqn{m}-dependent errors: A
 difference-based approach}. Submitted.
}
\seealso{
\code{\link[stats]{acf}}, \code{\link[dbacf]{plot.dbacf}},
          \code{\link[dbacf]{selectM}}
}

