% Generated by roxygen2 (4.1.0): do not edit by hand
% Please edit documentation in R/selectM.R
\name{selectM}
\alias{selectM}
\title{Selection of parameter \eqn{m} in change-point regression with
 \eqn{m}-dependent errors}
\usage{
selectM(data, diff = TRUE, d = 1, alpha = 0.05, plot = TRUE, ...)
}
\arguments{
\item{data}{numeric vector or a univariate object of class
                \code{\link[stats]{ts}} of length at least \code{1e2}.}

\item{diff}{logical indicating whether the sequence of ratios is computed
                from series of first differences (default) or from original
                series. For highly fluctuating signals with significantly
                large jumps, \code{diff = TRUE} diminishes the influence of
                the unkown signal over the sequence of ratios.}

\item{d}{numeric scalar indicating the weight used to compute
                the denominator of the ratio of difference-based estimators;
                at \code{d = 1} (default) that denominator has minimal bias.}

\item{alpha}{numeric scalar giving the level of significance at which the
                empirical confidence interval is computed.}

\item{plot}{logical. If \code{TRUE} (default) the sequence of ratios is
                plotted.}

\item{...}{further arguments passed to \code{\link{plot.selectM}}.}
}
\value{
An object of class "selectM" containing:
 \item{ratio}{numeric vector of length \code{lag.max} giving a sequence
              of ratios of difference-based estimators.}
 \item{confInt}{numeric vector of length 2 giving the lower and upper end
                of a confidence interval (at \code{alpha} percent of significance)
                for a plausible value of \eqn{m}.}
 \item{diff}{logical indicating whether ratios are computed from series
             of first differences (default) or from original series.}
 \item{d}{numeric scalar indicating the weight used to compute denominator
         of ratios of difference-based estimators.}
 \item{alpha}{a numeric indicating the level of significance of empirical
              confidence interval.}
 \item{lag.max}{integer scalar specifying the maximum unit in time at which
                the values of the sequence of ratios are computed.}
 \item{series}{string with name of variable \code{data}.}
}
\description{
Without pre-estimation of underlying signal, this function provides a graphical
 procedure allowing for selection of underlying level of dependency \eqn{m}.
 To that end, a sequence of ratios of difference-based estimators is computed
 according to Eq. (6.1) of \cite{Munk and Tecuapetla-Gómez (2015)}; an empirical
 confidence interval for plausible values of \eqn{m} is also computed. Details
 on how to interpret this method are given below.
}
\details{
This function is based on the asymptotic properties of a ratio,
 \eqn{r_h} say, of two difference-based estimators, cf. Eq. (6.1) of
 \cite{Munk and Tecuapetla-Gómez (2015)}. To simplify matters suppose
 that observations are pure noise, i.e., no signal is present and consequently
 \code{diff = FALSE} should be chosen. Let \eqn{\gamma(\cdot)}{\gamma()} denote the theoretical
 autocovariance function of this pure noise process. Then,
 at convergence (in probability), if \eqn{h\leq m}{h \le m}, \eqn{r_h} approximates
 \eqn{1-\gamma(h)/\gamma(0)} and \eqn{1} otherwise. Hence a plausible value for
 \eqn{m}, \eqn{\hat{m}}{m*} say, is one such that \eqn{r_h\approx 1}{r_h -> 1} for
 \eqn{h \geq \hat{m} + 1}{h \ge m* + 1}. Such a plausible value for \eqn{m} can be determined by
 considering the confidence interval associated with the hypothesis \eqn{H_0: r_h = 1},
 for \eqn{h \geq m + 1}{h \ge m + 1}. In order to build such an interval, the empirical
 distribution of \eqn{r_h} is used: the lower and upper ends of the interval
 are given by \code{quantile(ratio, alpha / 2)} and \code{quantile(ratio, 1 - alpha / 2)},
 respectively, here \code{ratio} is a vector containing the values of \eqn{r_h}
 for \eqn{h = 1, \ldots, \code{min(sqrt(n), 1e3)}}{h = 1, \ldots, min(sqrt(n), 1e3)},
 where \code{n = length(data)}.

 For highly fluctuating signals with significantly large jumps, the procedure
 described above is affected by the \emph{quadratic variation} of the signal and it
 is recommendable to apply it on the series of first differences
 (\code{diff = TRUE}). In accordance with this modification, a plausible
 estimate for \eqn{m}, \eqn{\hat{m}}{m*} say, is a value such that \eqn{r_h\approx 1}{r_h -> 1}
 for \eqn{h \geq \hat{m} + 2}{h \ge m* + 2}; the corresponding confidence interval for
 plausible values of \eqn{m} is calculated as above. See Section 6 of
 \cite{Munk and Tecuapetla-Gómez (2015)} for further details.
}
\examples{
ma3 <- arima.sim(n = 1e4, model = list(ma = c(2, 2, 1), order = c (0, 0, 3)),
                 sd = 1)
output.selectM <- selectM(ma3, plot = FALSE)
output.selectMNoDiff <- selectM(ma3, diff = FALSE, plot = FALSE)
par(mfrow = c(2,1))
plot(output.selectM) # from this plot: m.hat = 5 - 2
plot(output.selectMNoDiff) # from this plot: m.hat = 4 - 1
}
\references{
Munk, A. and Tecuapetla-Gómez, I. (2015).
 \emph{Autocovariance estimation in change-point regression with
 \eqn{m}-dependent errors: A difference-based approach}. Submitted.
}
\seealso{
\code{\link[dbacf]{plot.selectM}}.
}

